@@ -1,21 +1,6 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2015-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """Fixtures for the server webserver."""
 
@@ -28,7 +13,7 @@ import dataclasses
 from http import HTTPStatus
 
 import pytest
-from PyQt5.QtCore import pyqtSignal, QUrl
+from qutebrowser.qt.core import pyqtSignal, QUrl
 
 from end2end.fixtures import testprocess
 
@@ -77,6 +62,7 @@ class Request(testprocess.Line):
             '/redirect-to': [HTTPStatus.FOUND],
             '/relative-redirect': [HTTPStatus.FOUND],
             '/absolute-redirect': [HTTPStatus.FOUND],
+            '/redirect-http/data/downloads/download.bin': [HTTPStatus.FOUND],
 
             '/cookies/set': [HTTPStatus.FOUND],
             '/cookies/set-custom': [HTTPStatus.FOUND],
@@ -84,7 +70,7 @@ class Request(testprocess.Line):
             '/500-inline': [HTTPStatus.INTERNAL_SERVER_ERROR],
             '/500': [HTTPStatus.INTERNAL_SERVER_ERROR],
         }
-        for i in range(15):
+        for i in range(25):
             path_to_statuses['/redirect/{}'.format(i)] = [HTTPStatus.FOUND]
         for suffix in ['', '1', '2', '3', '4', '5', '6']:
             key = ('/basic-auth/user{suffix}/password{suffix}'
