@@ -1,28 +1,13 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2016-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """Tests for the global page history."""
 
 import logging
 
 import pytest
-from PyQt5.QtCore import QUrl
+from qutebrowser.qt.core import QUrl
 
 from qutebrowser.browser import history
 from qutebrowser.utils import urlutils, usertypes
@@ -276,7 +261,7 @@ class TestHistoryInterface:
     @pytest.fixture
     def hist_interface(self, web_history):
         # pylint: disable=invalid-name
-        QtWebKit = pytest.importorskip('PyQt5.QtWebKit')
+        QtWebKit = pytest.importorskip('qutebrowser.qt.webkit')
         from qutebrowser.browser.webkit import webkithistory
         QWebHistoryInterface = QtWebKit.QWebHistoryInterface
         # pylint: enable=invalid-name
@@ -304,7 +289,7 @@ class TestInit:
             history.web_history.setParent(None)
             history.web_history = None
         try:
-            from PyQt5.QtWebKit import QWebHistoryInterface
+            from qutebrowser.qt.webkit import QWebHistoryInterface
             QWebHistoryInterface.setDefaultInterface(None)
         except ImportError:
             pass
@@ -313,7 +298,7 @@ class TestInit:
                                          usertypes.Backend.QtWebKit])
     def test_init(self, backend, qapp, tmpdir, data_tmpdir, monkeypatch, cleanup_init):
         if backend == usertypes.Backend.QtWebKit:
-            pytest.importorskip('PyQt5.QtWebKitWidgets')
+            pytest.importorskip('qutebrowser.qt.webkitwidgets')
         else:
             assert backend == usertypes.Backend.QtWebEngine
 
@@ -322,7 +307,7 @@ class TestInit:
         assert history.web_history.parent() is qapp
 
         try:
-            from PyQt5.QtWebKit import QWebHistoryInterface
+            from qutebrowser.qt.webkit import QWebHistoryInterface
         except ImportError:
             QWebHistoryInterface = None
 
@@ -471,7 +456,7 @@ class TestRebuild:
         # Trigger a completion rebuild
         monkeypatch.setattr(web_history.database, 'user_version_changed', lambda: True)
 
-        with pytest.raises(Exception, match='tick-tock'):
+        with pytest.raises(stubs.FakeHistoryTick, match='tick-tock'):
             history.WebHistory(web_history.database, progress=progress)
 
         assert web_history.metainfo['force_rebuild']
