@@ -193,6 +193,33 @@ def test_is_available(available, mocker):
     assert pdfjs.is_available() == available
 
 
+@pytest.mark.parametrize('found_file', [
+    "build/pdf.js",
+    "build/pdf.mjs",
+])
+def test_get_pdfjs_js_path(found_file: str, monkeypatch: pytest.MonkeyPatch):
+    def fake_pdfjs_res(requested):
+        if requested.endswith(found_file):
+            return
+        raise pdfjs.PDFJSNotFound(requested)
+
+    monkeypatch.setattr(pdfjs, 'get_pdfjs_res', fake_pdfjs_res)
+    assert pdfjs.get_pdfjs_js_path() == found_file
+
+
+def test_get_pdfjs_js_path_none(monkeypatch: pytest.MonkeyPatch):
+    def fake_pdfjs_res(requested):
+        raise pdfjs.PDFJSNotFound(requested)
+
+    monkeypatch.setattr(pdfjs, 'get_pdfjs_res', fake_pdfjs_res)
+
+    with pytest.raises(
+        pdfjs.PDFJSNotFound,
+        match="Path 'build/pdf.js or build/pdf.mjs' not found"
+    ):
+        pdfjs.get_pdfjs_js_path()
+
+
 @pytest.mark.parametrize('mimetype, url, enabled, expected', [
     # PDF files
     ('application/pdf', 'http://www.example.com', True, True),
